@@ -1,6 +1,7 @@
+use std::path::{Path, PathBuf};
 use std::{env, fs, io};
 
-use std::path::{Path, PathBuf};
+use indoc::indoc;
 use thiserror::Error;
 
 mod cli;
@@ -38,6 +39,48 @@ fn main() -> Result<(), GitMitInstallError> {
     install_hook(&hooks, "prepare-commit-msg")?;
     install_hook(&hooks, "pre-commit")?;
     install_hook(&hooks, "commit-msg")?;
+
+    if let Some("global") = matches.value_of("scope") {
+        mit_commit_message_lints::console::style::success(
+            "git-mit will be added for newly created or cloned repositories",
+            "inside existing repositories run \"git init\" to set them up",
+        );
+    } else {
+        mit_commit_message_lints::console::style::success(
+            "git-mit is setup for the current repository",
+            indoc! {r#"
+                Optionally you can install git-mit for all new "git clone" and "git init" commands
+
+                git mit-install --scope=global
+            "#},
+        );
+    }
+
+    mit_commit_message_lints::console::style::success(
+        "Adding your first pairing partners",
+        indoc! {r#"
+            git mit-config mit set bt "Billie Thompson" billie@example.com
+            git mit-config mit set se "Someone Else" someone@example.com
+
+            To add multiple users to your commit run. Remember to include yourself!
+
+            git mit bt se
+
+            Optionally you can also add a issue number by running
+
+            git mit-relates-to "[#134]"
+
+            When you can use the "-m" flag or your editor, both work as normal
+
+            git commit -m "Your message"
+
+            The authors and issue number appear on the commit. These authors are saved into your current repository for ad-hoc pairing. When you're ready make the authors everywhere run
+
+            mkdir -p "$HOME/.config/git-mit"
+            git mit-config generate > "$HOME/.config/git-mit/mit.toml"
+        "#},
+    );
+
     Ok(())
 }
 
